package com.hzya.frame.sys.proof.dao.impl;

import com.hzya.frame.sys.appApi.entity.AppApi;
import com.hzya.frame.sys.appApi.entity.AppApiDto;
import com.hzya.frame.sys.appApi.entity.AppApiListVo;
import com.hzya.frame.sys.proof.entity.ProofEntity;
import com.hzya.frame.sys.proof.entity.PullVo;
import org.springframework.stereotype.Repository;
import com.hzya.frame.basedao.dao.MybatisGenericDao;
import com.hzya.frame.sys.proof.dao.IProofDao;

import java.util.List;

/**
 * @description: 凭证  dao
 * @tableName: sys_proof
 * @entityName: ProofEntity
 * @author: gjh
 * @history: 1.0
 */
@Repository("sys_proofdao")
public class ProofDaoImpl extends MybatisGenericDao<ProofEntity, String> implements IProofDao {

    @Override
    public List<PullVo> queryProject(PullVo pullVo) {
        List<PullVo> o = (List<PullVo>) super.selectList(getSqlIdPrifx() + "queryProject", pullVo);
        return o;
    }

    @Override
    public List<PullVo> querySupplier(PullVo pullVo) {
        List<PullVo> o = (List<PullVo>) super.selectList(getSqlIdPrifx() + "querySupplier", pullVo);
        return o;
    }
    @Override
    public List<PullVo> queryClient(PullVo pullVo) {
        List<PullVo> o = (List<PullVo>) super.selectList(getSqlIdPrifx() + "queryClient", pullVo);
        return o;
    }
    @Override
    public List<PullVo> querySalesman(PullVo pullVo) {
        List<PullVo> o = (List<PullVo>) super.selectList(getSqlIdPrifx() + "querySalesman", pullVo);
        return o;
    }
    @Override
    public List<PullVo> querySection(PullVo pullVo) {
        List<PullVo> o = (List<PullVo>) super.selectList(getSqlIdPrifx() + "querySection", pullVo);
        return o;
    }
    @Override
    public List<PullVo> querySob(PullVo pullVo) {
        List<PullVo> o = (List<PullVo>) super.selectList(getSqlIdPrifx() + "querySob", pullVo);
        return o;
    }
    @Override
    public List<PullVo> queryReceiptConf(PullVo pullVo) {
        List<PullVo> o = (List<PullVo>) super.selectList(getSqlIdPrifx() + "queryReceiptConf", pullVo);
        return o;
    }
    @Override
    public List<PullVo> queryFzhs(PullVo pullVo) {
        List<PullVo> o = (List<PullVo>) super.selectList(getSqlIdPrifx() + "queryFzhs", pullVo);
        return o;
    }
    @Override
    public List<PullVo> querySubject(PullVo pullVo) {
        List<PullVo> o = (List<PullVo>) super.selectList(getSqlIdPrifx() + "querySubject", pullVo);
        return o;
    }
    @Override
    public List<ProofEntity> queryProofPrepare(ProofEntity pullVo) {
        List<ProofEntity> o = (List<ProofEntity>) super.selectList(getSqlIdPrifx() + "queryProofPrepare", pullVo);
        return o;
    }
    @Override
    public List<ProofEntity> queryPushProof(ProofEntity pullVo) {
        List<ProofEntity> o = (List<ProofEntity>) super.selectList(getSqlIdPrifx() + "queryPushProof", pullVo);
        return o;
    }

    @Override
    public List<PullVo> queryXM(PullVo pullVo) {
        List<PullVo> o = (List<PullVo>) super.selectList(getSqlIdPrifx() + "queryXM", pullVo);
        return o;
    }
    @Override
    public List<PullVo> queryGys(PullVo pullVo) {
        List<PullVo> o = (List<PullVo>) super.selectList(getSqlIdPrifx() + "queryGys", pullVo);
        return o;
    }
    @Override
    public List<PullVo> queryKh(PullVo pullVo) {
        List<PullVo> o = (List<PullVo>) super.selectList(getSqlIdPrifx() + "queryKh", pullVo);
        return o;
    }
    @Override
    public List<PullVo> queryYwy(PullVo pullVo) {
        List<PullVo> o = (List<PullVo>) super.selectList(getSqlIdPrifx() + "queryYwy", pullVo);
        return o;
    }
    @Override
    public List<PullVo> queryBm(PullVo pullVo) {
        List<PullVo> o = (List<PullVo>) super.selectList(getSqlIdPrifx() + "queryBm", pullVo);
        return o;
    }
}
